# Managing Fact Sheet Subscriptions (GraphQL)
### On this page
  * [Get Subscription Roles](https://help.sap.com/docs/leanix/ea/managing-fact-sheet-subscriptions#get-subscription-roles)
  * [Create a Fact Sheet Subscription](https://help.sap.com/docs/leanix/ea/managing-fact-sheet-subscriptions#create-a-fact-sheet-subscription)
  * [Get Fact Sheet Subscriptions](https://help.sap.com/docs/leanix/ea/managing-fact-sheet-subscriptions#get-fact-sheet-subscriptions)
  * [Update a Fact Sheet Subscription](https://help.sap.com/docs/leanix/ea/managing-fact-sheet-subscriptions#update-a-fact-sheet-subscription)
  * [Delete a Fact Sheet Subscription](https://help.sap.com/docs/leanix/ea/managing-fact-sheet-subscriptions#delete-a-fact-sheet-subscription)


Manage fact sheet subscriptions using the GraphQL API.
Subscriptions let you configure a set of custom permissions and responsibilities in relation to fact sheets for various user groups within your organization. To learn more about subscriptions, see [Fact Sheet Subscription](https://help.sap.com/docs/leanix/ea/fact-sheet-subscription?locale=en-US&state=PRODUCTION&version=CLOUD "Fact sheet subscription assigns responsibility and accountability to users for maintaining data. Learn about fact sheet subscriptions, including types, roles, and how to assign and subscribe to fact sheets to promote stakeholder involvement and ensure data accuracy and completeness.").
